#
# spec file for package tix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tix
BuildRequires:  autoconf
BuildRequires:  fdupes
BuildRequires:  tcl-devel
BuildRequires:  tk-devel
BuildRequires:  pkgconfig(x11)
Version:        8.4.3
Release:        75.4
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Tools for tk
License:        BSD-3-Clause
Group:          Development/Libraries/Tcl
Source:         Tix%version-src.tar.bz2
Patch0:         %name.patch
Patch1:         %name-c89.patch
Patch2:         %name-implicit-int.patch
Patch3:         %name-includes.patch
%requires_ge    tcl
%requires_ge    tk

%description
The Tix library has, by far, the greatest collection of widgets for
programming with Tcl/Tk. Highlights include: hierarchical list box,
directory list/tree view, spreadsheet, tabular list box, combo box,
Motif style file select box, MS Windows style file select box, paned
window, note book, spin control widget and many more. With these new
widgets, your applications will look great and interact with your users
in intuitive ways.

%prep
%autosetup -p0 -n Tix%version
find docs -type f | xargs chmod a-x

%build
autoreconf
export CFLAGS="$RPM_OPT_FLAGS -DUSE_INTERP_RESULT -fno-strict-aliasing"
%configure \
	--with-tcl=%_libdir \
	--with-tk=%_libdir
make

%install
make install DESTDIR=%buildroot libdir=%_libdir/tcl
MANN=%buildroot/%_mandir/mann
mkdir -p $MANN
pushd man
for f in *.n; do
  sed -e '/man\.macros/r man.macros' -e '/man\.macros/d' $f > $MANN/$f
done
popd

%files
%defattr(-,root,root)
%doc ABOUT* README* ChangeLog license.terms index.html
%doc docs/Release* docs/*html docs/img docs/pdf/* demos
%doc %_mandir/*/*
%_libdir/tcl

%changelog
* Tue Nov  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Split %%requires_ge tcl tk into two lines: simple workaround
  against the macro missing to add a newline in some cases.
* Mon Jul  1 2024 Reinhard Max <max@suse.com>
- boo#1225944: Add patches to build with gcc14:
  * tix-c89.patch
  * tix-implicit-int.patch
  * tix-includes.patch
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Feb 19 2018 crrodriguez@opensuse.org
- Remove buildrequires on xorg-x11-devel
- apps linked to tcl/tk static stubs must %%require_ge tcl tk
* Thu Jun 20 2013 max@suse.com
- Fix build with Tcl 8.6.0.
- Cleanup spec file.
* Wed Dec 21 2011 coolo@suse.com
- tcl's license is BSD-3-Clause
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Fri Apr  4 2008 max@suse.de
- New version 8.4.3, works with Tcl/Tk 8.5.
* Tue Jun  5 2007 max@suse.de
- New version: 8.4.0
- Lots of cleanup and bugs fixed.
- Better per-default compliance with rpmlint.
- The 'tixwish' executable is gone.  Use tclsh or wish and load the
  Tix package dynamically.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jul 29 2005 max@suse.de
- Moved script library to /usr/share/tcl .
* Thu Feb  5 2004 max@suse.de
- Building as a shared lib again.
- Added -fno-strict-aliasing to CFLAGS.
* Thu Jan 15 2004 max@suse.de
- New version: 8.1.4
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Jul 23 2003 max@suse.de
- Added tk-devel to neededforbuild.
* Tue May 20 2003 ro@suse.de
- remove .cvsignore files
- fix filelist
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
- changed neededforbuild <xdevel> to <>
* Tue Jul  9 2002 max@suse.de
- Ready for Tcl/Tk 8.4.
- Doesn't break on KDE3 anymore [Bug #16428].
* Wed Apr 10 2002 max@suse.de
- Fixed for new version of autobuild.
* Wed Feb 20 2002 max@suse.de
- Fixed for lib64-s390x.
* Thu Jan 17 2002 max@suse.de
- New version 8.1.3
- Tix is a separate package again. The new version is able to build
  without having the Tcl/Tk sources at hand.
- Don't build static libs anymore.
* Tue Nov 24 1998 max@suse.de
- merged spec-files into tcl_new.spec
* Mon Nov 23 1998 max@suse.de
- building with new Tcl/Tk version: 8.0.4
- tixwish is now dynamically linked to libtcl
* Wed Sep 23 1998 ro@suse.de
- added to specfile: applx patch for tcl8.0
* Thu May 14 1998 hf@suse.de
- english and german README.SuSE
* Mon Feb 23 1998 hf@suse.de
- changed README.SuSE
* Mon Feb 16 1998 hf@suse.de
- changes in spec file
* Thu Feb  5 1998 hf@suse.de
  new package Tix for Tcl/Tk 8.0
  and new directorypath to tcl/tk in /usr/lib/tcltk
